@@ -5,8 +5,9 @@ from .trade import Trade
 from .position import Position
 from .currency_pair import CurrencyPair
 from .order_book import OrderBook
-from .order import Order
+from .order import Order, Orders
 from .enums import OrderSide, OrderType, OrderDuration, OrderStatus, PositionType
+from .tick import Tick
 
 __all__ = (
     'Bot',
@@ -17,10 +18,11 @@ __all__ = (
     'CurrencyPair',
     'OrderBook',
     'Order',
-
+    'Orders',
     'OrderSide',
     'OrderType',
     'OrderDuration',
+    'Tick',
     'PositionType',
     'OrderStatus',
 )
